@@ -15,7 +15,13 @@ class Experiment:
             )
             response = response.json()
         except:
-            raise Exception("Unable to connect to the server")
+            try:
+                response = requests.get(
+                    f"http://const_server:8000/experiments/{experiment_id}",
+                )
+                response = response.json()
+            except:
+              raise Exception("Unable to connect to the server")
         try:
             graph = response["pipelineJSON"]
             project = response["project"]
