@@ -8,6 +8,7 @@ from ...util.data_types import get_dataframe_types
 # @function_error_handling("train_test_split")
 def train_test_split(**params):
     data = params["data"]
+    print(params["parameters"]["test_size"])
     train_dataset, test_dataset = sklearn_tts(
         data, test_size=params["parameters"]["test_size"], random_state=42
     )
@@ -20,6 +21,7 @@ def train_model(**params):
     y = data[params["column"]]
     X = data.drop(params["column"], axis=1)
     data_dict  = get_dataframe_types(X)
+    print(X.head())
     model = params["model"]
     Model = model.fit(X, y)
     filename = 'model.joblib'
