@@ -100,7 +100,7 @@ export const preprocessingOptions = [
       },
       {
         name: "missing_values",
-        type: "any", //int | float | str | np.nan| None |pandas.NA
+        type: "any", //int | number | str | np.nan| None |pandas.NA
         defaultValue: "np.nan",
         render: true,
         optional: true,
@@ -144,7 +144,7 @@ export const preprocessingOptions = [
         name: "axis",
         type: "select",
         options: [0, 1],
-        defaultValue: 0,
+        defaultValue: 1,
         render: true,
         optional: true,
       },
@@ -687,7 +687,7 @@ export const preprocessingOptions = [
       {
         name: "dtype",
         type: "str",
-        defaultValue: "np.float64",
+        defaultValue: "np.number64",
         render: true,
         optional: true,
       },
@@ -743,7 +743,7 @@ export const preprocessingOptions = [
       {
         name: "dtype",
         type: "str",
-        defaultValue: "np.float",
+        defaultValue: "np.number",
         render: true,
         optional: true,
       },
@@ -765,14 +765,14 @@ export const preprocessingOptions = [
       },
       {
         name: "min_frequency",
-        type: "float",
+        type: "number",
         defaultValue: "None",
         render: true,
         optional: true,
       },
       {
         name: "max_categories",
-        type: "integer",
+        type: "number",
         defaultValue: "None",
         render: true,
         optional: true,
@@ -887,14 +887,14 @@ export const preprocessingOptions = [
     parameters: [
       {
         name: "lower",
-        type: "float",
+        type: "number",
         defaultValue: 'None',
         render: true,
         optional: true,
       },
       {
         name: "upper",
-        type: "float",
+        type: "number",
         defaultValue: 'None',
         render: true,
         optional: true,
