@@ -46,7 +46,7 @@ class ModelHandler:
             "multi_class": params["multi_class"],
             "tol": params["tol"],
         }
-        return f"model = huble.sklearn.logistic_regression({parameters})"
+        return f"model = huble.sklearn.logistic_regression(parameters={parameters})"
 
     def __svm_svc(self, params):
         parameters = {
