@@ -2,31 +2,43 @@ import numpy as np
 import pandas as pd
 from scipy import stats
 
+
 def verify_ml_dataset(dataset, target):
     # check for null values in pandas dataframe
     DATA_IMBALANCE_THRESHOLD = 0.1
     TOO_MANY_ZEROES_THRESHOLD = 0.1
     FEATURE_IMPORTANCE_THRESHOLD = 0.01
     dict_main = {}
-    dict_main["errors"]={"null_values":[],  "string_features":[]}
-    dict_main["warnings"]={"too_many_zeros":[], "outliers":[], "data_imbalance":[], "data_normalization":[]}
-    dict_main["success"]={"null_values":[],  "string_features":[], "too_many_zeros":[], "outliers":[], "data_imbalance":[], "data_normalization":[]}
-    dict_main["status"] = 'ok'
+    dict_main["errors"] = {"null_values": [], "string_features": []}
+    dict_main["warnings"] = {
+        "too_many_zeros": [],
+        "outliers": [],
+        "data_imbalance": [],
+        "data_normalization": [],
+    }
+    dict_main["success"] = {
+        "null_values": [],
+        "string_features": [],
+        "too_many_zeros": [],
+        "outliers": [],
+        "data_imbalance": [],
+        "data_normalization": [],
+    }
+    dict_main["status"] = "ok"
 
-       
     for column in dataset.columns:
 
         # check for null values in pandas dataframe
         if dataset[column].isnull().values.any():
             dict_main["errors"]["null_values"].append(column)
-            dict_main["status"] = 'error'
+            dict_main["status"] = "error"
         else:
             dict_main["success"]["null_values"].append(column)
 
         # check for string columns in pandas dataframe
-        if (dataset[column].dtypes == object)==False:
+        if (dataset[column].dtypes == object) == False:
             dict_main["errors"]["string_features"].append(column)
-            dict_main["status"] = 'error'
+            dict_main["status"] = "error"
         else:
             dict_main["success"]["string_features"].append(column)
 
@@ -45,21 +57,19 @@ def verify_ml_dataset(dataset, target):
             # Select data points with a z-scores above or below 3
             # filtered_entries = (abs_z_scores < 3)
             # print(filtered_entries)
-            if (abs_z_scores < 3).all() :
+            if (abs_z_scores < 3).all():
                 dict_main["warnings"]["outliers"].append(column)
             else:
                 dict_main["success"]["outliers"].append(column)
 
         # Data normalization
-        if column in dict_main["success"]["string_features"]:  
-          if  dataset[column].min()< -1 or dataset[column].max()>1:
-            dict_main["warnings"]["data_normalization"].append(column)
-            break
-          else:      
-            dict_main["success"]["data_normalization"].append(column)
-         
+        if column in dict_main["success"]["string_features"]:
+            if dataset[column].min() < -1 or dataset[column].max() > 1:
+                dict_main["warnings"]["data_normalization"].append(column)
+                break
+            else:
+                dict_main["success"]["data_normalization"].append(column)
 
-    
     values = dataset[target].value_counts()
     if (
         values[0] * DATA_IMBALANCE_THRESHOLD > values[1]
@@ -68,6 +78,5 @@ def verify_ml_dataset(dataset, target):
         dict_main["warnings"]["data_imbalance"].append("data_imbalance")
     else:
         dict_main["success"]["data_imbalance"].append("data_imbalance")
-    
 
     return dict_main.popitem()
